View source: R/trainUBaymodel.R
| sampleInitial | R Documentation |
Sample initial solutions using a probabilistic version of Greedy algorithm.
sampleInitial(post_scores, constraints, size)
post_scores |
a vector of posterior scores (prior scores + likelihood) for each feature |
constraints |
a list containing feature-wise constraints |
size |
initial number of samples to be created. The output sample size can be lower, since duplicates are removed. |
a matrix containing initial feature sets as rows
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.